/************************************************************************/
/*																		*/
/*	AMP2.cpp		--		Definition for AMP2 library 	   			*/
/*																		*/
/************************************************************************/
/*	Author:		Eric Marsh												*/
/*	Copyright 2016, Digilent Inc.										*/
/************************************************************************/
/*  File Description:													*/
/*		This file defines functions for the PmodAMP2					*/
/*																		*/
/************************************************************************/
/*  Revision History:													*/
/*																		*/
/*	06/28/2016(EricM): created											*/
/*																		*/
/************************************************************************/


/* ------------------------------------------------------------ */
/*				Include File Definitions						*/
/* ------------------------------------------------------------ */
#include "AMP2.h"
#include <Dspi.h>

/* ------------------------------------------------------------ */
/*				Procedure Definitions							*/
/* ------------------------------------------------------------ */

/* ------------------------------------------------------------ */
/*        AMP2::AMP2
**
**        Synopsis:
**				
**        Parameters:
**
**
**
**        Return Values:
**                void 
**
**        Errors:
**
**
**        Description:
**			Class constructor. Performs variables initialization tasks
**
**
*/
AMP2::AMP2()
{
	pdspi = NULL;
	
}

/* ------------------------------------------------------------ */
/*        AMP2::begin
**
**        Synopsis:
**				myAMP2.begin(PAR_ACCESS_SPI0);
**        Parameters:
**				uint8_t bAccessType	- the SPI interface where the Pmod is connected. It can be one of:
**					0	PAR_ACCESS_SPI0	- indicates SPI port 2, connetor JB
**					1	PAR_ACCESS_SPI1	- indicates SPI port 1, connector J1
**				uint8_t spd - The frequency at which the SPI clock should be set to. 2 Mhz by default
**
**        Return Values:
**                void 
**
**        Errors:
**
**
**        Description:
**				This function initializes the specific SPI interface used, setting the SPI frequency to the parameter spd, which is 1 Mhz by default.
**
*/
void AMP2::begin(uint8_t bAccessType, uint32_t spd, uint8_t SSpin)
{
	
	if(bAccessType == PAR_ACCESS_SPI0)
	{
		pdspi = new DSPI0();
		m_SSPin = PIN_DSPI0_SS;	// default SS pin for SPI0
	}
	if(bAccessType == PAR_ACCESS_SPI1)
	{
		pdspi = new DSPI1();
		m_SSPin = PIN_DSPI1_SS;	// default SS pin for SPI1
	}
	if(pdspi != NULL)
	{
		// if SSpin was passed in as a parameter, set m_SSPin to it.
		if( SSpin != NULL)
		{
			m_SSPin = SSpin;
		}
		pdspi->begin(m_SSPin);
		pdspi->setMode(DSPI_MODE0);
		pdspi->setSpeed(spd);
	}
}

/* ------------------------------------------------------------ */
/*        AMP2::PlayFreq
**
**        Synopsis:
**				myAMP2.PlayFreq(391.995, 70); 
**        Parameters:
**				double freqHz - Frequency to play
**				int durationMs - How long the note should play, in milliseconds
**        Return Values:
**                void 
**
**        Errors:
**
**
**        Description:
**				Function to play music notes
**
*/
void AMP2::PlayFreq(double freqHz, int durationMs){
  //Calculate the period in microseconds
  int periodMicro = int((1/freqHz)*1000000);
  int halfPeriod = periodMicro/2;
   
  //store start time
  int startTime = millis();
   
  //(millis() - startTime) is elapsed play time
  while((millis() - startTime) < durationMs){
    digitalWrite(m_SSPin, HIGH);
    delayMicroseconds(halfPeriod);
    digitalWrite(m_SSPin, LOW);
    delayMicroseconds(halfPeriod);
  }
}