/************************************************************************/
/*									*/
/*  AMP2Demo.pde	-- Example demo for AMP2			*/
/*									*/
/************************************************************************/
/*  Author:	Eric Marsh						*/
/*  Copyright (c) 2016, Digilent Inc.  	    				*/
/************************************************************************/
/************************************************************************/
/*  Module Description:							*/
/*									*/
/*  This sketch is an example on on how to play notes to a speaker      */
/*  using the PmodAMP2                                                  */
/************************************************************************/
/*  Revision History:							*/
/*									*/
/*  6/28/2016(Eric M): Created                                          */
/*									*/
/************************************************************************/
/************************************************************************/
/*  Board Support:							*/
/*									*/
/*  chipKit UC32 - See fritzing image for more details                  */
/*  chipKit Max32                                             	        */
/************************************************************************/

/* -------------------------------------------------------------------- */
/*		        Include File Definitions                     	*/
/* -------------------------------------------------------------------- */

#include <DSPI.h>
#include <AMP2.h>

/* -------------------------------------------------------------------- */
/*		            Global Variables                     	*/
/* -------------------------------------------------------------------- */
AMP2 myAMP2; 

// globals defining music notes for the song
double A_4 = 440.000;
double A_6 = 1760.00;
double A_7 = 3520.00;
double A_SHARP_4 = 466.164;
double A_SHARP_6 = 1864.66;
double B_4 = 493.883;
double B_6 = 1975.53;
double C_5 = 523.521;
double C_7 = 2093.00;
double D_7 = 2349.32;
double E_6 = 1318.51;
double E_7 = 2637.02;
double F_7 = 2793.83;
double G_4 = 391.995;
double G_6 = 1567.98;
double G_7 = 3135.96;
double G_SHARP_4 = 415.305;


// array containing music notes, to be passed to PlaySong()
double marioSong[78] = { E_7, E_7, 0, E_7, 0, C_7, E_7, 0, G_7, 0, 0,
  0, G_6, 0, 0, 0, C_7, 0, 0, G_6, 0, 0, E_6, 0, 0, A_6, 0, B_6,
  0, A_SHARP_6, A_6, 0, G_6, E_7, G_7, A_7, 0, F_7, G_7, 0, E_7, 0, C_7,
  D_7, B_6, 0, 0, C_7, 0, 0, G_6, 0, 0, E_6, 0, 0, A_6, 0, B_6,
  0, A_SHARP_6, A_6, 0, G_6, E_7, G_7, A_7, 0, F_7, G_7, 0, E_7, 0, C_7,
  D_7, B_6, 0, 0 };
 
// array containing the tempo for the notes above, to be passed to PlaySong()
int tempo[] = {  12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12,
  12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12,
  12, 12, 12, 12, 9, 9, 9, 12, 12, 12, 12, 12, 12, 12, 12,
  12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12,
  12, 12, 12, 12, 9, 9, 9, 12, 12, 12, 12, 12, 12, 12, 12,
  12, 12, 12, 12};

int marioSongLength = 78;

/* -------------------------------------------------------------------- */
/*	               Procedure Definitions	                        */
/* -------------------------------------------------------------------- */
/***	setup
**
**	Parameters:
**		none
**
**	Return Value:
**		none
**
**	Errors:
**		none
**
**	Description:
**		 Performs basic initialization.		
/*** ---------------------------------------------------------- ***/
void setup()
{
  // initialize PmodAMP2
  myAMP2.begin(PAR_ACCESS_SPI0);
}


/*** ---------------------------------------------------------- ***/
/***	loop
**
**	Parameters:
**		none
**
**	Return Value:
**		none
**
**	Errors:
**		none
**
**	Description:
**		Main program module. Enters the main program loop.
/*** ---------------------------------------------------------- ***/
void loop()
{
  // play a framilliar song
  PlaySong(marioSong, tempo, marioSongLength);

  // wait some time
  delay(1000);
  
}


/*** ---------------------------------------------------------- ***/
/***	PlaySong
**
**	Parameters:
**		double *song - pointer to an array of doubles, with each double composing a note in a song.
**              double *tempo - pointer to an array of integers, with each int saying how long to play note
**              int lengthSong - how many elements are in the 
**
**	Return Value:
**		void
**
**	Errors:
**		none
**
**	Description:
**		Takes a song passed through a song and tempo array, and uses playFreq() function in the AMP2 library
**              to play the song.
/*** ---------------------------------------------------------- ***/
void PlaySong(double *song, int *tempo, int lengthSong)
{
  double note;
  for(int i = 0; i < lengthSong; i++)
  {
    note = song[i];
    if(note != 0)
    {
      myAMP2.PlayFreq(note, 1000 / tempo[i]);  
    }
	delay(1000 /tempo[i]);
  }
}
